@@ -1,4 +1,4 @@
 # -*- coding: utf-8 -*-
 from django import dispatch
 
-monitor_up_check = dispatch.Signal(providing_args=[])
+monitor_up_check = dispatch.Signal()
